==> v1.2020.19.tar.gz: plantuml/src/net/sourceforge/plantuml/skin/ActorStyle.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.skin;

import net.sourceforge.plantuml.graphic.SymbolContext;
import net.sourceforge.plantuml.graphic.TextBlock;
import net.sourceforge.plantuml.graphic.USymbol;

public enum ActorStyle {

	STICKMAN, STICKMAN_BUSINESS, AWESOME;

	public USymbol toUSymbol() {
		if (this == STICKMAN) {
			return USymbol.ACTOR_STICKMAN;
		} else if (this == AWESOME) {
			return USymbol.ACTOR_AWESOME;
		}
		throw new IllegalStateException();
	}

	public TextBlock getTextBlock(SymbolContext symbolContext) {
		if (this == STICKMAN) {
			return new ActorStickMan(symbolContext, false);
		} else if (this == STICKMAN_BUSINESS) {
			return new ActorStickMan(symbolContext, true);
		} else if (this == AWESOME) {
			return new ActorAwesome(symbolContext);
		}
		throw new IllegalStateException();
	}

}

==> v1.2021.4.tar.gz: plantuml/src/net/sourceforge/plantuml/skin/ActorStyle.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.skin;

import net.sourceforge.plantuml.graphic.SymbolContext;
import net.sourceforge.plantuml.graphic.TextBlock;
import net.sourceforge.plantuml.graphic.USymbol;

public enum ActorStyle {

	STICKMAN, STICKMAN_BUSINESS, AWESOME, HOLLOW;

	public USymbol toUSymbol() {
		if (this == STICKMAN) {
			return USymbol.ACTOR_STICKMAN;
		} else if (this == AWESOME) {
			return USymbol.ACTOR_AWESOME;
		} else if (this == HOLLOW) {
			return USymbol.ACTOR_HOLLOW;
		}
		throw new IllegalStateException();
	}

	public TextBlock getTextBlock(SymbolContext symbolContext) {
		if (this == STICKMAN) {
			return new ActorStickMan(symbolContext, false);
		} else if (this == STICKMAN_BUSINESS) {
			return new ActorStickMan(symbolContext, true);
		} else if (this == AWESOME) {
			return new ActorAwesome(symbolContext);
		} else if (this == HOLLOW) {
			return new ActorHollow(symbolContext);
		}
		throw new IllegalStateException();
	}

}
